@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-python
-# Copyright(C) 2018 Fridolin Pokorny
+# Copyright(C) 2018, 2019, 2020 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,14 +18,10 @@
 """Configuration used for computing recommendations."""
 
 import os
-import json
 
 import attr
 
-_DEFAULT_WAREHOUSES = (
-    'https://pypi.python.org/simple',
-    'https://pypi.org/simple'
-)
+_DEFAULT_WAREHOUSES = ("https://pypi.python.org/simple", "https://pypi.org/simple")
 
 
 @attr.s(slots=True)
@@ -41,8 +37,8 @@ class _Configuration:
     @warehouses.default
     def warehouses_default(self):
         warehouses = _DEFAULT_WAREHOUSES
-        if 'THOTH_PYTHON_WAREHOUSES' in os.environ:
-            warehouses = os.environ['THOTH_PYTHON_WAREHOUSES'].split(',')
+        if "THOTH_PYTHON_WAREHOUSES" in os.environ:
+            warehouses = os.environ["THOTH_PYTHON_WAREHOUSES"].split(",")
 
         return warehouses
 
